@@ -17,10 +17,12 @@
 #include <folly/Conv.h>
 #include <folly/Portability.h>
 
+#include <folly/coro/AwaitResult.h>
 #include <folly/coro/Baton.h>
 #include <folly/coro/BlockingWait.h>
 #include <folly/coro/Invoke.h>
 #include <folly/coro/Mutex.h>
+#include <folly/coro/Ready.h>
 #include <folly/coro/SharedMutex.h>
 #include <folly/coro/Task.h>
 #include <folly/coro/detail/InlineTask.h>
@@ -158,12 +160,12 @@ static coro::Task<void> parentRequest(int id) {
   coro::Baton baton2;
 
   auto fut1 =
-      childRequest(mutex, baton1)
-          .scheduleOn(co_await coro::co_current_executor)
+      co_withExecutor(
+          co_await coro::co_current_executor, childRequest(mutex, baton1))
           .start();
   auto fut2 =
-      childRequest(mutex, baton1)
-          .scheduleOn(co_await coro::co_current_executor)
+      co_withExecutor(
+          co_await coro::co_current_executor, childRequest(mutex, baton1))
           .start();
 
   CHECK_EQ(contextData, RequestContext::get()->getContextData(testToken1));
@@ -196,8 +198,8 @@ TEST_F(TaskTest, RequestContextIsPreservedAcrossSuspendResume) {
 
   // Context should be captured at coroutine co_await time and not at
   // call time.
-  auto task1 = parentRequest(1).scheduleOn(&executor);
-  auto task2 = parentRequest(2).scheduleOn(&executor);
+  auto task1 = co_withExecutor(&executor, parentRequest(1));
+  auto task2 = co_withExecutor(&executor, parentRequest(2));
 
   {
     RequestContextScopeGuard nestedRequestScope;
@@ -269,8 +271,8 @@ TEST_F(TaskTest, ContextPreservedAcrossMutexLock) {
 
   folly::coro::Baton event1;
   folly::coro::Baton event2;
-  auto t1 = handleRequest(event1).scheduleOn(&manualExecutor).start();
-  auto t2 = handleRequest(event2).scheduleOn(&manualExecutor).start();
+  auto t1 = co_withExecutor(&manualExecutor, handleRequest(event1)).start();
+  auto t2 = co_withExecutor(&manualExecutor, handleRequest(event2)).start();
 
   manualExecutor.drain();
 
@@ -323,7 +325,7 @@ TEST_F(TaskTest, RequestContextSideEffectsArePreserved) {
   folly::ManualExecutor executor;
   folly::coro::Baton baton;
 
-  auto t = g(baton).scheduleOn(&executor).start();
+  auto t = co_withExecutor(&executor, g(baton)).start();
 
   executor.drain();
 
@@ -403,6 +405,23 @@ TEST_F(TaskTest, TaskOfLvalueReferenceAsTry) {
   }());
 }
 
+TEST_F(TaskTest, TaskOfLvalueReferenceAsResult) {
+  folly::coro::blockingWait([]() -> folly::coro::Task<void> {
+    auto returnIntRef = [](int& value) -> folly::coro::Task<int&> {
+      co_return value;
+    };
+
+    int value = 123;
+    auto&& res = co_await co_await_result(returnIntRef(value));
+    CHECK(res.has_value());
+    CHECK_EQ(&value, &res.value_or_throw());
+    CHECK_EQ(&value, &(co_await folly::coro::co_ready(std::move(res))));
+
+    int& valueRef = co_await returnIntRef(value);
+    CHECK_EQ(&value, &valueRef);
+  }());
+}
+
 TEST_F(TaskTest, CancellationPropagation) {
   folly::coro::blockingWait([]() -> folly::coro::Task<void> {
     auto token = co_await folly::coro::co_current_cancellation_token;
@@ -453,7 +472,7 @@ TEST_F(TaskTest, StartInlineUnsafe) {
       co_await folly::coro::co_reschedule_on_current_executor;
       hasFinished = true;
     };
-    auto sf = makeTask().scheduleOn(executor).startInlineUnsafe();
+    auto sf = co_withExecutor(executor, makeTask()).startInlineUnsafe();
 
     // Check that the task started inline on the current thread.
     // It should not yet have completed, however, since the rest
@@ -484,7 +503,7 @@ TEST_F(TaskTest, StartInlineUnsafePreservesRequestContext) {
       co_await baton;
       EXPECT_EQ(childCtx, RequestContext::try_get());
     };
-    auto sf = makeTask().scheduleOn(executor).startInlineUnsafe();
+    auto sf = co_withExecutor(executor, makeTask()).startInlineUnsafe();
 
     EXPECT_TRUE(hasStarted);
     EXPECT_EQ(parentCtx, RequestContext::try_get());
@@ -574,19 +593,17 @@ TEST_F(TaskTest, MakeTask) {
 TEST_F(TaskTest, ScheduleOnRestoresExecutor) {
   folly::ScopedEventBaseThread ebt;
   folly::coro::blockingWait([&]() -> folly::coro::Task<void> {
-    co_await [&]() -> folly::coro::Task<void> {
+    co_await co_withExecutor(&ebt, [&]() -> folly::coro::Task<void> {
       EXPECT_TRUE(ebt.getEventBase()->inRunningEventBaseThread());
       co_return;
-    }()
-                          .scheduleOn(&ebt);
+    }());
     EXPECT_FALSE(ebt.getEventBase()->inRunningEventBaseThread());
     try {
-      co_await [&]() -> folly::coro::Task<void> {
+      co_await co_withExecutor(&ebt, [&]() -> folly::coro::Task<void> {
         EXPECT_TRUE(ebt.getEventBase()->inRunningEventBaseThread());
         throw std::runtime_error("");
         co_return;
-      }()
-                            .scheduleOn(&ebt);
+      }());
     } catch (...) {
     }
     EXPECT_FALSE(ebt.getEventBase()->inRunningEventBaseThread());
@@ -598,7 +615,7 @@ TEST_F(TaskTest, CoAwaitTryWithScheduleOn) {
     auto t = []() -> folly::coro::Task<int> { co_return 42; }();
 
     folly::Try<int> result = co_await folly::coro::co_awaitTry(
-        std::move(t).scheduleOn(folly::getGlobalCPUExecutor()));
+        co_withExecutor(folly::getGlobalCPUExecutor(), std::move(t)));
     EXPECT_EQ(42, result.value());
   }());
 }
@@ -619,7 +636,7 @@ TEST_F(TaskTest, CoAwaitTryWithScheduleOnAndCancellation) {
       folly::Try<int> result = co_await folly::coro::co_withCancellation(
           cancelSrc.getToken(),
           folly::coro::co_awaitTry(
-              makeTask().scheduleOn(folly::getGlobalCPUExecutor())));
+              co_withExecutor(folly::getGlobalCPUExecutor(), makeTask())));
       EXPECT_EQ(42, result.value());
     }
 
@@ -629,7 +646,7 @@ TEST_F(TaskTest, CoAwaitTryWithScheduleOnAndCancellation) {
       folly::Try<int> result =
           co_await folly::coro::co_awaitTry(folly::coro::co_withCancellation(
               cancelSrc.getToken(),
-              makeTask().scheduleOn(folly::getGlobalCPUExecutor())));
+              co_withExecutor(folly::getGlobalCPUExecutor(), makeTask())));
       EXPECT_EQ(42, result.value());
     }
   }());
@@ -706,7 +723,7 @@ TEST_F(TaskTest, CoAwaitNothrowWithScheduleOn) {
         auto t = []() -> folly::coro::Task<int> { co_return 42; }();
 
         int result = co_await folly::coro::co_nothrow(
-            std::move(t).scheduleOn(folly::getGlobalCPUExecutor()));
+            co_withExecutor(folly::getGlobalCPUExecutor(), std::move(t)));
         EXPECT_EQ(42, result);
 
         t = []() -> folly::coro::Task<int> {
@@ -715,7 +732,7 @@ TEST_F(TaskTest, CoAwaitNothrowWithScheduleOn) {
 
         try {
           result = co_await folly::coro::co_nothrow(
-              std::move(t).scheduleOn(folly::getGlobalCPUExecutor()));
+              co_withExecutor(folly::getGlobalCPUExecutor(), std::move(t)));
         } catch (...) {
           ADD_FAILURE();
         }
@@ -786,7 +803,7 @@ TEST_F(TaskTest, CoYieldCoErrorSameExecutor) {
     co_yield folly::coro::co_error(ExpectedException());
   };
   auto scopeAndThrowWrapper = [&]() -> folly::coro::Task<void> {
-    co_await scopeAndThrow().scheduleOn(ebThread.getEventBase());
+    co_await co_withExecutor(ebThread.getEventBase(), scopeAndThrow());
   };
 
   EXPECT_THROW(
