@@ -16,22 +16,17 @@
 
 #include <folly/debugging/symbolizer/Symbolizer.h>
 
-#include <climits>
-#include <cstdio>
 #include <cstdlib>
-#include <iostream>
 
 #include <folly/FileUtil.h>
 #include <folly/Memory.h>
 #include <folly/ScopeGuard.h>
-#include <folly/String.h>
 #include <folly/Synchronized.h>
 #include <folly/container/EvictingCacheMap.h>
+#include <folly/debugging/symbolizer/Dwarf.h>
+#include <folly/debugging/symbolizer/Elf.h>
+#include <folly/debugging/symbolizer/ElfCache.h>
 #include <folly/debugging/symbolizer/detail/Debug.h>
-#include <folly/experimental/symbolizer/Dwarf.h>
-#include <folly/experimental/symbolizer/Elf.h>
-#include <folly/experimental/symbolizer/ElfCache.h>
-#include <folly/experimental/symbolizer/LineReader.h>
 #include <folly/lang/SafeAssert.h>
 #include <folly/lang/ToAscii.h>
 #include <folly/memory/SanitizeAddress.h>
@@ -203,6 +198,25 @@ using CachedSymbolizedFrames =
 
 using UnsyncSymbolCache = EvictingCacheMap<uintptr_t, CachedSymbolizedFrames>;
 
+/**
+ * @param instructionAddr The address of an instruction after it has been
+ * adjusted by the linker's `l_addr`.
+ * @return true if the given address is contained in an executable segment of
+ * `elfFile`.
+ */
+bool containedInExecutableSegment(
+    const ElfFile& elfFile, ElfAddr instructionAddr) {
+  return elfFile.iterateProgramHeaders([&](const ElfPhdr& sh) {
+    bool executable = sh.p_flags & PF_X;
+    bool loadable = sh.p_type == PT_LOAD;
+    if (!(executable && loadable)) {
+      return false;
+    }
+    return sh.p_vaddr <= instructionAddr &&
+        instructionAddr < (sh.p_vaddr + sh.p_memsz);
+  });
+}
+
 } // namespace
 
 struct Symbolizer::SymbolCache : public Synchronized<UnsyncSymbolCache> {
@@ -334,9 +348,11 @@ size_t Symbolizer::symbolize(
 
       // Get the unrelocated, ELF-relative address by normalizing via the
       // address at which the object is loaded.
-      auto const adjusted = addr - reinterpret_cast<uintptr_t>(lmap->l_addr);
+      auto const eaddr = static_cast<ElfAddr>(addr);
+      auto const maddr = lmap->l_addr;
+      auto const adjusted = eaddr < maddr ? ~ElfAddr(0) : eaddr - maddr;
       size_t numInlined = 0;
-      if (elfFile->getSectionContainingAddress(adjusted)) {
+      if (containedInExecutableSegment(*elfFile, adjusted)) {
         if (mode_ == LocationInfoMode::FULL_WITH_INLINE &&
             frameCount > addrCount) {
           size_t maxInline = std::min<size_t>(
