@@ -19,6 +19,7 @@
 #include <stdint.h>
 
 #include <random>
+#include <tuple>
 #include <unordered_map>
 #include <unordered_set>
 #include <utility>
@@ -560,7 +561,7 @@ TEST(Hash, hashBool10) {
 }
 
 TEST(Hash, stdTuple) {
-  typedef std::tuple<int64_t, std::string, int32_t> tuple3;
+  using tuple3 = std::tuple<int64_t, std::string, int32_t>;
   tuple3 t(42, "foo", 1);
 
   std::unordered_map<tuple3, std::string> m;
@@ -600,7 +601,7 @@ TEST(Hash, enumType) {
 }
 
 TEST(Hash, pairFollyHash) {
-  typedef std::pair<int64_t, int32_t> pair2;
+  using pair2 = std::pair<int64_t, int32_t>;
   pair2 p(42, 1);
 
   std::unordered_map<pair2, std::string, folly::Hash> m;
@@ -609,7 +610,7 @@ TEST(Hash, pairFollyHash) {
 }
 
 TEST(Hash, tupleFollyHash) {
-  typedef std::tuple<int64_t, int32_t, int32_t> tuple3;
+  using tuple3 = std::tuple<int64_t, int32_t, int32_t>;
   tuple3 t(42, 1, 1);
 
   std::unordered_map<tuple3, std::string, folly::Hash> m;
@@ -661,7 +662,7 @@ TEST(Hash, commutativeHashCombine) {
 }
 
 TEST(Hash, stdTupleDifferentHash) {
-  typedef std::tuple<int64_t, std::string, int32_t> tuple3;
+  using tuple3 = std::tuple<int64_t, std::string, int32_t>;
   tuple3 t1(42, "foo", 1);
   tuple3 t2(9, "bar", 3);
   tuple3 t3(42, "foo", 3);
@@ -859,6 +860,9 @@ static_assert(
     !folly::IsAvalanchingHasher<std::hash<long double>, long double>::value);
 static_assert(
     folly::IsAvalanchingHasher<std::hash<std::string>, std::string>::value);
+static_assert(
+    folly::IsAvalanchingHasher<std::hash<std::string_view>, std::string_view>::
+        value);
 static_assert(
     !folly::IsAvalanchingHasher<std::hash<TestEnum>, TestEnum>::value);
 static_assert(
@@ -1061,6 +1065,18 @@ TEST(Traits, stdHashStringAvalances) {
       });
 }
 
+TEST(Traits, stdHashStringViewAvalances) {
+  verifyAvalanching<std::hash<std::string_view>, std::string>(
+      "00000000000000000000000000000", [](std::string& str) {
+        std::size_t i = 0;
+        while (str[i] == '1') {
+          str[i] = '0';
+          ++i;
+        }
+        str[i] = '1';
+      });
+}
+
 TEST(Traits, follyHashUint64Avalances) {
   verifyAvalanching<folly::Hash>(uint64_t{0}, [](uint64_t& v) { v++; });
 }
@@ -1078,3 +1094,49 @@ TEST(Traits, follyHasherFloatAvalanches) {
 TEST(Traits, follyHasherDoubleAvalanches) {
   verifyAvalanching<folly::hasher<double>>(0.0, [](double& v) { v += 1; });
 }
+
+TEST(HashSequence, Fold) {
+  EXPECT_EQ(folly::hash::detail::hash_sequence(folly::hasher<int>{}), 0);
+  EXPECT_EQ(
+      folly::hash::detail::hash_sequence(folly::hasher<int>{}, 1),
+      folly::hasher<int>{}(1));
+  EXPECT_EQ(
+      folly::hash::detail::hash_sequence(folly::hasher<int>{}, 1, 2),
+      folly::hash::hash_128_to_64(
+          folly::hasher<int>{}(1), folly::hasher<int>{}(2)));
+  EXPECT_EQ(
+      folly::hash::detail::hash_sequence(folly::hasher<int>{}, 1, 2, 3),
+      folly::hash::hash_128_to_64(
+          folly::hasher<int>{}(1),
+          folly::hash::hash_128_to_64(
+              folly::hasher<int>{}(2), folly::hasher<int>{}(3))));
+}
+
+TEST(HashSequence, TypeMix) {
+  EXPECT_EQ(
+      folly::hash::detail::hash_sequence(
+          folly::detail::hash_one, 1, 1.0, std::string_view{"hello"}),
+      folly::hash::hash_128_to_64(
+          folly::hasher<int>{}(1),
+          folly::hash::hash_128_to_64(
+              folly::hasher<double>{}(1.0),
+              folly::hasher<std::string_view>{}("hello"))));
+}
+
+TEST(HashTuple, Empty) {
+  auto empty = std::make_tuple<>();
+  EXPECT_EQ(
+      folly::hash::detail::hash_tuple(folly::hasher<decltype(empty)>{}, empty),
+      0);
+}
+
+TEST(HashTuple, Basic) {
+  auto basic = std::make_tuple<int, double, std::string>(1, 1.0, "hello");
+  EXPECT_EQ(
+      folly::hash::detail::hash_tuple(folly::detail::hash_one, basic),
+      folly::hash::hash_128_to_64(
+          folly::hasher<int>{}(1),
+          folly::hash::hash_128_to_64(
+              folly::hasher<double>{}(1.0),
+              folly::hasher<std::string>{}("hello"))));
+}
