@@ -327,8 +327,7 @@ static folly::Indestructible<SQGroupInfoRegistry> sSQGroupInfoRegistry;
 
 template <class... Args>
 IoUringProvidedBufferRing::UniquePtr makeProvidedBufferRing(Args&&... args) {
-  return IoUringProvidedBufferRing::UniquePtr(
-      new IoUringProvidedBufferRing(std::forward<Args>(args)...));
+  return IoUringProvidedBufferRing::create(std::forward<Args>(args)...);
 }
 
 #else
@@ -1122,7 +1121,11 @@ void IoUringBackend::initSubmissionLinked() {
           .ringSizeShift = ringShift,
           .useHugePages = false,
       };
-      bufferProvider_ = makeProvidedBufferRing(this->ioRingPtr(), options);
+      for (size_t i = 0; i < options_.providedBufRings; i++) {
+        bufferProviders_.push_back(
+            makeProvidedBufferRing(this->ioRingPtr(), options));
+        options.gid = nextBufferProviderGid();
+      }
     } catch (const IoUringProvidedBufferRing::LibUringCallError& ex) {
       LOG(ERROR) << folly::to<std::string>(
           "failed to make provided buffer ring, buffer count: ",
@@ -1169,6 +1172,14 @@ void IoUringBackend::delayedInit() {
     initSubmissionLinked();
   }
 
+  if (useReqBatching()) {
+    int iowait_ret = ::io_uring_set_iowait(&ioRing_, false);
+    if (iowait_ret) {
+      LOG(FATAL) << "Failed to set NO_IOWAIT flag: "
+                 << folly::errnoStr(-iowait_ret);
+    }
+  }
+
   if (options_.registerRingFd) {
     // registering just has some perf impact, so no need to fall back
 #if FOLLY_IO_URING_UP_TO_DATE
