@@ -164,6 +164,19 @@ class IoUringBackend : public EventBaseBackendBase {
       return *this;
     }
 
+    constexpr bool isPow2(uint64_t n) noexcept {
+      return n > 0 && !((n - 1) & n);
+    }
+
+    Options& setProvidedBufRings(size_t v) {
+      if (!isPow2(v)) {
+        throw std::runtime_error(folly::to<std::string>(
+            "number of provided buffer rings must be a power of 2"));
+      }
+      providedBufRings = v;
+      return *this;
+    }
+
     Options& setRegisterRingFd(bool v) {
       registerRingFd = v;
 
@@ -248,6 +261,7 @@ class IoUringBackend : public EventBaseBackendBase {
     size_t sqGroupNumThreads{1};
     size_t initialProvidedBuffersCount{0};
     size_t initialProvidedBuffersEachSize{0};
+    size_t providedBufRings{1};
 
     uint32_t flags{0};
 
@@ -419,7 +433,12 @@ class IoUringBackend : public EventBaseBackendBase {
   void cancel(IoSqeBase* sqe);
 
   // built in buffer provider
-  IoUringBufferProviderBase* bufferProvider() { return bufferProvider_.get(); }
+  IoUringBufferProviderBase* bufferProvider() {
+    return bufferProviders_
+        [bufferProviderIdx_++ & (bufferProviders_.size() - 1)]
+            .get();
+  }
+  bool hasBufferProvider() { return bufferProviders_.size() > 0; }
   uint16_t nextBufferProviderGid() { return bufferProviderGidNext_++; }
   IoUringZeroCopyBufferPool* zcBufferPool() { return zcBufferPool_.get(); }
 
@@ -1150,7 +1169,8 @@ class IoUringBackend : public EventBaseBackendBase {
   // submit
   IoSqeBaseList submitList_;
   uint16_t bufferProviderGidNext_{0};
-  IoUringBufferProviderBase::UniquePtr bufferProvider_;
+  std::vector<IoUringBufferProviderBase::UniquePtr> bufferProviders_;
+  uint64_t bufferProviderIdx_{0};
   IoUringZeroCopyBufferPool::UniquePtr zcBufferPool_;
 
   // loop related
