@@ -24,7 +24,6 @@
 
 #if defined(FOLLY_USE_JEMALLOC) && (!defined(FOLLY_SANITIZE) || !FOLLY_SANITIZE)
 #include <jemalloc/jemalloc.h>
-#endif
 
 using namespace folly;
 
@@ -161,8 +160,4 @@ TEST_F(MallctlHelperTest, valid_call_via_cache) {
   EXPECT_NO_THROW(call());
 }
 
-int main(int argc, char** argv) {
-  ::testing::InitGoogleTest(&argc, argv);
-  folly::Init init(&argc, &argv);
-  return usingJEMalloc() ? RUN_ALL_TESTS() : 0;
-}
+#endif
