@@ -129,7 +129,8 @@ TEST(Result, storeAndGetStoppedResult) {
   // Constructing with `OperationCancelled` without the legacy path
   // is debug-fatal.
   if (kIsDebug) {
-    EXPECT_DEATH({ non_value_result::from_exception_wrapper(ocEw); }, deathRe);
+    EXPECT_DEATH(
+        { (void)non_value_result::from_exception_wrapper(ocEw); }, deathRe);
   } else {
     auto ew =
         non_value_result::from_exception_wrapper(ocEw).to_exception_wrapper();
@@ -336,13 +337,6 @@ TEST(Result, moveFromUnderlying) {
 // The point is that `std::move` is not required in `return` / `co_return`,
 // even when there's an "value/error" -> "result" conversion taking place.
 RESULT_CO_TEST(Result, movableContexts) {
-  {
-    auto fn = []() -> result<std::unique_ptr<int>> {
-      auto fivePtr = std::make_unique<int>(5);
-      return fivePtr;
-    };
-    EXPECT_EQ(5, *(co_await fn()));
-  }
   {
     auto fn = []() -> result<std::unique_ptr<int>> {
       auto fivePtr = std::make_unique<int>(5);
